@@ -3,9 +3,9 @@ package jdk.javadoc.internal.tool.resources;
 public final class version extends java.util.ListResourceBundle {
     protected final Object[][] getContents() {
         return new Object[][] {
-            { "full", "18.0.1.1+2" },
-            { "jdk", "18.0.1.1" },
-            { "release", "18.0.1.1" },
+            { "full", "20.0.1+9" },
+            { "jdk", "20.0.1" },
+            { "release", "20.0.1" },
         };
     }
 }
