@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,9 +26,8 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (C) 1991-2016 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in 
- * http://www.unicode.org/copyright.html.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
+ * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
  * a copy of the Unicode data files and any associated documentation
@@ -37,14 +36,11 @@
  * without restriction, including without limitation the rights to use,
  * copy, modify, merge, publish, distribute, and/or sell copies of
  * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that
- * (a) this copyright and permission notice appear with all copies 
- * of the Data Files or Software,
- * (b) this copyright and permission notice appear in associated 
- * documentation, and
- * (c) there is clear notice in each modified Data File or in the Software
- * as well as in the documentation associated with the Data File(s) or
- * Software that the data or software has been modified.
+ * or Software are furnished to do so, provided that either
+ * (a) this copyright and permission notice appear with all copies
+ * of the Data Files or Software, or
+ * (b) this copyright and permission notice appear in associated
+ * Documentation.
  *
  * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
  * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
@@ -70,19 +66,74 @@ import java.util.ListResourceBundle;
 public class FormatData_sw_KE extends ListResourceBundle {
     @Override
     protected final Object[][] getContents() {
-        final String[] metaValue_java_time_buddhist_DatePatterns = new String[] {
-               "EEEE, d MMMM y G",
-               "d MMMM y G",
-               "d MMM y G",
-               "dd/MM/y GGGGG",
-            };
-        final String[] metaValue_buddhist_DatePatterns = new String[] {
-               "EEEE, d MMMM y GGGG",
-               "d MMMM y GGGG",
-               "d MMM y GGGG",
-               "dd/MM/y G",
-            };
+        final String[] metaValue_generic_TimePatterns = new String[] {
+            "HH:mm:ss zzzz",
+            "HH:mm:ss z",
+            "HH:mm:ss",
+            "HH:mm",
+        };
+        final String metaValue_generic_DateFormatItem_GyMd = "d/M/y G";
+        final String[] metaValue_java_time_generic_DatePatterns = new String[] {
+            "EEEE, d MMMM y G",
+            "d MMMM y G",
+            "d MMM y G",
+            "dd/MM/y GGGGG",
+        };
+        final String[] metaValue_generic_DatePatterns = new String[] {
+            "EEEE, d MMMM y GGGG",
+            "d MMMM y GGGG",
+            "d MMM y GGGG",
+            "dd/MM/y G",
+        };
         final Object[][] data = new Object[][] {
+            { "generic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.generic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "generic.DatePatterns", metaValue_generic_DatePatterns },
+            { "generic.DateTimePatterns",
+                new String[] {
+                    "{1}, {0}",
+                    "{1}, {0}",
+                    "{1}, {0}",
+                    "{1}, {0}",
+                }
+            },
+            { "generic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
+            { "TimePatterns", metaValue_generic_TimePatterns },
+            { "DatePatterns",
+                new String[] {
+                    "EEEE, d MMMM y",
+                    "d MMMM y",
+                    "d MMM y",
+                    "dd/MM/y",
+                }
+            },
+            { "DateTimePatterns",
+                new String[] {
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                    "{1} {0}",
+                }
+            },
+            { "DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
+            { "buddhist.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.buddhist.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "buddhist.DatePatterns", metaValue_generic_DatePatterns },
+            { "buddhist.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
+            { "japanese.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.japanese.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "japanese.DatePatterns", metaValue_generic_DatePatterns },
+            { "japanese.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
+            { "roc.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.roc.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "roc.DatePatterns", metaValue_generic_DatePatterns },
+            { "roc.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
+            { "islamic.TimePatterns", metaValue_generic_TimePatterns },
+            { "java.time.islamic.DatePatterns", metaValue_java_time_generic_DatePatterns },
+            { "islamic.DatePatterns", metaValue_generic_DatePatterns },
+            { "islamic.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
+            { "islamic-civil.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
+            { "islamic-umalqura.DateFormatItem.GyMd", metaValue_generic_DateFormatItem_GyMd },
             { "latn.NumberElements",
                 new String[] {
                     ".",
@@ -96,13 +147,10 @@ public class FormatData_sw_KE extends ListResourceBundle {
                     "\u2030",
                     "\u221e",
                     "NaN",
+                    "",
+                    "",
                 }
             },
-            { "japanese.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "buddhist.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "java.time.japanese.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "latn.NumberPatterns",
                 new String[] {
                     "#,##0.###",
@@ -149,9 +197,6 @@ public class FormatData_sw_KE extends ListResourceBundle {
                     "{one:trilioni' '000 other:trilioni' '000}",
                 }
             },
-            { "java.time.islamic.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
-            { "roc.DatePatterns", metaValue_buddhist_DatePatterns },
-            { "islamic.DatePatterns", metaValue_buddhist_DatePatterns },
         };
         return data;
     }
