@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -274,6 +274,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Tongaski cas",
                "",
             };
+        final String[] Yukon = new String[] {
+               "Yukonowy cas",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Alaska = new String[] {
                "Alaskojski standardny cas",
                "",
@@ -442,6 +450,14 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Chathamski cas",
                "",
             };
+        final String[] ETC_UTC = new String[] {
+               "koordin\u011browany sw\u011btowy cas",
+               "UTC",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Ecuador = new String[] {
                "Ekuadorski cas",
                "",
@@ -786,14 +802,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "Kapverdski cas",
                "",
             };
-        final String[] EMPTY_ZONE = new String[] {
-               "",
-               "",
-               "",
-               "",
-               "",
-               "",
-            };
         final String[] East_Timor = new String[] {
                "P\u00f3dzajt\u0161notimorski cas",
                "",
@@ -971,27 +979,27 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
                "",
             };
         final String[] Europe_Central = new String[] {
-               "Srjej\u017aoeuropski standardny cas",
+               "Srjej\u017anoeuropejski standardny cas",
                "MEZ",
-               "Srjej\u017aoeuropski l\u011b\u015bojski cas",
+               "Srjej\u017anoeuropejski l\u011b\u015bojski cas",
                "MESZ",
-               "Srjej\u017aoeuropski cas",
+               "Srjej\u017anoeuropejski cas",
                "MEZ",
             };
         final String[] Europe_Eastern = new String[] {
-               "P\u00f3dzajt\u0161noeuropski standardny cas",
+               "P\u00f3dzajt\u0161noeuropejski standardny cas",
                "OEZ",
-               "P\u00f3dzajt\u0161noeuropski l\u011b\u015bojski cas",
+               "P\u00f3dzajt\u0161noeuropejski l\u011b\u015bojski cas",
                "OESZ",
-               "P\u00f3dzajt\u0161noeuropski cas",
+               "P\u00f3dzajt\u0161noeuropejski cas",
                "OEZ",
             };
         final String[] Europe_Western = new String[] {
-               "P\u00f3dwjacornoeuropski standardny cas",
+               "P\u00f3dwjacornoeuropejski standardny cas",
                "WEZ",
-               "P\u00f3dwjacornoeuropski l\u011b\u015bojski cas",
+               "P\u00f3dwjacornoeuropejski l\u011b\u015bojski cas",
                "WESZ",
-               "P\u00f3dwjacornoeuropski cas",
+               "P\u00f3dwjacornoeuropejski cas",
                "WEZ",
             };
         final String[] Mexico_Pacific = new String[] {
@@ -1212,7 +1220,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Tokyo", Japan },
             { "Europe/Bucharest", Europe_Eastern },
             { "Asia/Shanghai", China },
-            { "UTC", EMPTY_ZONE },
+            { "UTC", ETC_UTC },
             { "ACT", Australia_Central },
             { "AET", Australia_Eastern },
             { "ART", Europe_Eastern },
@@ -1237,6 +1245,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "CST6CDT", America_Central },
             { "EST5EDT", America_Eastern },
             { "Etc/GMT", GMT },
+            { "Etc/UTC", ETC_UTC },
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Aden", Arabian },
@@ -1246,7 +1255,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
             { "Asia/Oral", Kazakhstan_Western },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Aqtau", Kazakhstan_Western },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
@@ -1255,7 +1263,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Aqtobe", Kazakhstan_Western },
@@ -1341,7 +1349,6 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
             { "Asia/Calcutta", India },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Dushanbe", Tajikistan },
             { "Asia/Jayapura", Indonesia_Eastern },
             { "Asia/Katmandu", Nepal },
@@ -1403,7 +1410,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
-            { "America/Dawson", America_Mountain },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1478,7 +1485,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1562,7 +1569,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1606,7 +1613,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
             { "Asia/Yekaterinburg", Yekaterinburg },
@@ -1649,6 +1656,7 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1692,7 +1700,9 @@ public class TimeZoneNames_dsb extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Cairo", "Kairo" },
             { "timezone.excity.Asia/Baghdad", "Bagdad" },
             { "timezone.excity.Asia/Bishkek", "Bi\u0161kek" },
+            { "timezone.excity.Asia/Karachi", "Kara\u010di" },
             { "timezone.excity.Asia/Nicosia", "Nikosia" },
+            { "timezone.excity.Asia/Rangoon", "Rangun" },
             { "timezone.excity.Asia/Tbilisi", "Tbilisi" },
             { "timezone.excity.Asia/Yakutsk", "Jakutsk" },
             { "timezone.excity.Asia/Yerevan", "Jerewan" },
