@@ -122,6 +122,14 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure de l\u2019Iran",
                "",
             };
+        final String[] Niue = new String[] {
+               "heure de Niou\u00e9",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Omsk = new String[] {
                "heure normale d\u2019Omsk",
                "",
@@ -218,6 +226,14 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
                "heure des A\u00e7ores",
                "",
             };
+        final String[] Brunei = new String[] {
+               "heure du Brun\u00e9i",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Easter = new String[] {
                "heure normale de l\u2019\u00eele de P\u00e2ques",
                "",
@@ -785,7 +801,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
-            { "Asia/Amman", Europe_Eastern },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dhaka", Bangladesh },
             { "Asia/Macau", China },
@@ -794,6 +809,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Africa/Juba", Africa_Central },
             { "Asia/Anadyr", Anadyr },
             { "Asia/Beirut", Europe_Eastern },
+            { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
             { "Asia/Hebron", Europe_Eastern },
             { "Asia/Kuwait", Arabian },
@@ -827,6 +843,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "Europe/Vaduz", Europe_Central },
             { "Pacific/Apia", Apia },
             { "Pacific/Fiji", Fiji },
+            { "Pacific/Niue", Niue },
             { "SystemV/AST4", Atlantic },
             { "SystemV/CST6", America_Central },
             { "SystemV/EST5", America_Eastern },
@@ -849,7 +866,6 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Jujuy", Argentina },
             { "America/Thule", Atlantic },
             { "Asia/Ashgabat", Turkmenistan },
-            { "Asia/Damascus", Europe_Eastern },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Sakhalin", Sakhalin },
             { "Asia/Tashkent", Uzbekistan },
@@ -1097,6 +1113,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/Scoresbysund", Greenland_Eastern },
             { "Antarctica/Macquarie", Australia_Eastern },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1124,6 +1141,7 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Asia/Thimphu", "Thimphou" },
+            { "timezone.excity.Pacific/Palau", "Palau" },
             { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Tripoli", "Tripoli [Libye]" },
@@ -1137,6 +1155,8 @@ public class TimeZoneNames_fr_CA extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Kitts", "Saint-Christophe-et-Ni\u00e9v\u00e8s" },
             { "timezone.excity.America/St_Thomas", "Saint Thomas" },
             { "timezone.excity.Europe/Isle_of_Man", "\u00eele de Man" },
+            { "timezone.excity.America/Tegucigalpa", "T\u00e9gucigalpa" },
+            { "timezone.excity.Antarctica/DumontDUrville", "Dumont d\u2019Urville" },
             { "timezone.excity.America/North_Dakota/Beulah", "Beulah [Dakota du Nord]" },
             { "timezone.excity.America/North_Dakota/Center", "Center [Dakota du Nord]" },
             { "timezone.excity.America/North_Dakota/New_Salem", "New Salem, Dakota du Nord" },
