@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -337,7 +337,6 @@ public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
             { "America/Juneau", Alaska },
@@ -359,7 +358,7 @@ public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
             { "America/Marigot", Atlantic },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -390,7 +389,7 @@ public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
             { "Indian/Kerguelen", French_Southern },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Johnston", Hawaii_Aleutian },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -410,7 +409,6 @@ public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
             { "America/Metlakatla", Alaska },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Antarctica/McMurdo", New_Zealand },
             { "Pacific/Kiritimati", Line_Islands },
             { "America/El_Salvador", America_Central },
@@ -429,6 +427,7 @@ public class TimeZoneNames_ps_PK extends TimeZoneNamesBundle {
             { "America/Rankin_Inlet", America_Central },
             { "America/Santa_Isabel", Mexico_Northwest },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
