@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -26,7 +26,7 @@
 /*
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2020 Unicode, Inc. All rights reserved.
+ * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
  * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
  *
  * Permission is hereby granted, free of charge, to any person obtaining
@@ -74,6 +74,22 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Alaska = new String[] {
+               "\u1c5f\u1c79\u1c5e\u1c5f\u1c65\u1c60\u1c5f \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
+               "",
+               "\u1c5f\u1c79\u1c5e\u1c5f\u1c65\u1c60\u1c5f \u1c65\u1c64\u1c67\u1c5f\u1c5c \u1c5a\u1c60\u1c5b\u1c5a",
+               "",
+               "\u1c5f\u1c79\u1c5e\u1c5f\u1c65\u1c60\u1c5f \u1c5a\u1c60\u1c5b\u1c5a",
+               "",
+            };
+        final String[] Amazon = new String[] {
+               "\u1c5f\u1c62\u1c5f\u1c61\u1c5a\u1c71 \u1c6e\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+               "\u1c5f\u1c62\u1c5f\u1c61\u1c5a\u1c71 \u1c65\u1c64\u1c5b\u1c69\u1c5d \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+               "\u1c5f\u1c62\u1c5f\u1c61\u1c5a\u1c71 \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+            };
         final String[] ETC_UTC = new String[] {
                "\u1c60\u1c5a\u1c68\u1c70\u1c64\u1c71\u1c6e\u1c74\u1c6e\u1c70 \u1c6d\u1c69\u1c71\u1c64\u1c63\u1c5f\u1c68\u1c65\u1c5f\u1c5e \u1c5a\u1c60\u1c5b\u1c5a",
                "UTC",
@@ -90,6 +106,14 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
                "\u1c6e\u1c74\u1c5e\u1c5f\u1c71\u1c74\u1c64\u1c60 \u1c5a\u1c60\u1c5b\u1c5a",
                "",
             };
+        final String[] Argentina = new String[] {
+               "\u1c5f\u1c79\u1c68\u1c61\u1c6e\u1c71\u1c74\u1c64\u1c71\u1c5f \u1c6e\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+               "\u1c5f\u1c79\u1c68\u1c61\u1c6e\u1c71\u1c74\u1c64\u1c71\u1c5f \u1c65\u1c64\u1c5b\u1c69\u1c5d \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+               "\u1c5f\u1c79\u1c68\u1c61\u1c6e\u1c71\u1c74\u1c64\u1c71\u1c5f \u1c5a\u1c60\u1c74\u1c5a",
+               "",
+            };
         final String[] Europe_Central = new String[] {
                "\u1c65\u1c6e\u1c71\u1c74\u1c68\u1c5f\u1c5e \u1c69\u1c68\u1c5a\u1c6f\u1c64\u1c6d\u1c5f\u1c71 \u1c6e\u1c65\u1c74\u1c6e\u1c71\u1c70\u1c5f\u1c68\u1c70 \u1c5a\u1c60\u1c5b\u1c5a",
                "",
@@ -153,12 +177,15 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
+            { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
+            { "America/Sitka", Alaska },
             { "Europe/Paris", Europe_Central },
             { "GMT", GMT },
             { "Europe/Bucharest", Europe_Eastern },
             { "UTC", ETC_UTC },
             { "ART", Europe_Eastern },
+            { "AST", Alaska },
             { "CST", America_Central },
             { "ECT", Europe_Central },
             { "PNT", America_Mountain },
@@ -171,7 +198,6 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "MST7MDT", America_Mountain },
             { "PST8PDT", America_Pacific },
             { "Asia/Gaza", Europe_Eastern },
-            { "Asia/Amman", Europe_Eastern },
             { "Africa/Lome", GMT },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Hebron", Europe_Eastern },
@@ -184,6 +210,7 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "Africa/Ceuta", Europe_Central },
             { "Africa/Dakar", GMT },
             { "Africa/Tunis", Europe_Central },
+            { "America/Nome", Alaska },
             { "Asia/Nicosia", Europe_Eastern },
             { "Europe/Malta", Europe_Central },
             { "Europe/Sofia", Europe_Eastern },
@@ -197,8 +224,8 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "Africa/Bissau", GMT },
             { "America/Aruba", Atlantic },
             { "America/Boise", America_Mountain },
+            { "America/Jujuy", Argentina },
             { "America/Thule", Atlantic },
-            { "Asia/Damascus", Europe_Eastern },
             { "Europe/Athens", Europe_Eastern },
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin", GMT },
@@ -221,8 +248,10 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Belize", America_Central },
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
-            { "America/Dawson", America_Mountain },
+            { "America/Cuiaba", Amazon },
             { "America/Inuvik", America_Mountain },
+            { "America/Juneau", Alaska },
+            { "America/Manaus", Amazon },
             { "America/Merida", America_Central },
             { "America/Nassau", America_Eastern },
             { "America/Panama", America_Eastern },
@@ -237,6 +266,7 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "Africa/Sao_Tome", GMT },
             { "Africa/Timbuktu", GMT },
             { "America/Antigua", Atlantic },
+            { "America/Cordoba", Argentina },
             { "America/Creston", America_Mountain },
             { "America/Curacao", Atlantic },
             { "America/Detroit", America_Eastern },
@@ -245,12 +275,14 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Jamaica", America_Eastern },
             { "America/Managua", America_Central },
             { "America/Marigot", Atlantic },
+            { "America/Mendoza", Argentina },
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
+            { "America/Yakutat", Alaska },
             { "Atlantic/Canary", Europe_Western },
             { "Atlantic/Faeroe", Europe_Western },
             { "Europe/Belgrade", Europe_Central },
@@ -267,6 +299,7 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "SystemV/EST5EDT", America_Eastern },
             { "SystemV/MST7MDT", America_Mountain },
             { "SystemV/PST8PDT", America_Pacific },
+            { "SystemV/YST9YDT", Alaska },
             { "America/Anguilla", Atlantic },
             { "America/Barbados", Atlantic },
             { "America/Dominica", Atlantic },
@@ -287,6 +320,9 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
             { "Africa/Nouakchott", GMT },
+            { "America/Boa_Vista", Amazon },
+            { "America/Catamarca", Argentina },
+            { "America/Chihuahua", America_Central },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
             { "America/Guatemala", America_Central },
@@ -307,9 +343,9 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Kralendijk", Atlantic },
             { "America/Louisville", America_Eastern },
             { "America/Martinique", Atlantic },
+            { "America/Metlakatla", Alaska },
             { "America/Montserrat", Atlantic },
             { "America/St_Vincent", Atlantic },
-            { "America/Whitehorse", America_Mountain },
             { "Atlantic/Jan_Mayen", Europe_Central },
             { "Atlantic/Reykjavik", GMT },
             { "Atlantic/St_Helena", GMT },
@@ -319,6 +355,7 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Fort_Nelson", America_Mountain },
             { "America/Mexico_City", America_Central },
             { "America/Pangnirtung", America_Eastern },
+            { "America/Porto_Velho", Amazon },
             { "America/Puerto_Rico", Atlantic },
             { "America/Rainy_River", America_Central },
             { "America/Tegucigalpa", America_Central },
@@ -326,11 +363,14 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Yellowknife", America_Mountain },
             { "Arctic/Longyearbyen", Europe_Central },
             { "America/Blanc-Sablon", Atlantic },
+            { "America/Buenos_Aires", Argentina },
+            { "America/Campo_Grande", Amazon },
             { "America/Danmarkshavn", GMT },
             { "America/Dawson_Creek", America_Mountain },
             { "America/Indiana/Knox", America_Central },
             { "America/Rankin_Inlet", America_Central },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -340,15 +380,22 @@ public class TimeZoneNames_sat extends TimeZoneNamesBundle {
             { "America/Swift_Current", America_Central },
             { "America/Bahia_Banderas", America_Central },
             { "America/Port-au-Prince", America_Eastern },
+            { "America/Argentina/Salta", Argentina },
             { "America/Indiana/Marengo", America_Eastern },
             { "America/Indiana/Winamac", America_Eastern },
+            { "America/Argentina/Tucuman", Argentina },
+            { "America/Argentina/Ushuaia", Argentina },
             { "America/Indiana/Tell_City", America_Central },
             { "America/Indiana/Vincennes", America_Eastern },
+            { "America/Argentina/La_Rioja", Argentina },
+            { "America/Argentina/San_Juan", Argentina },
+            { "America/Argentina/San_Luis", Argentina },
             { "America/Indiana/Petersburg", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
             { "timezone.excity.Etc/Unknown", "\u1c75\u1c5f\u1c5d \u1c6a\u1c64\u1c71\u1c66\u1c5f\u1c79\u1c63 \u1c75\u1c5f\u1c61\u1c5f\u1c68" },
+            { "America/Argentina/Rio_Gallegos", Argentina },
             { "America/North_Dakota/New_Salem", America_Central },
         };
         return data;
